App class

A class that defines the apps objects received from calling getInstalledApps method.

Constructors

App({String? appName, String? packageName, String? versionName, Uint8List? decodedIcon, String? installDate, String? lastUpdateDate})
App.fromMap(Map map)
factory

Properties

appName → String?
final
decodedIcon → Uint8List?
decoded app icon from base64 encode received from the native side.
final
hashCode → int
The hash code for this object.
no setterinherited
installDate → String?
final
lastUpdateDate → String?
final
packageName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionName → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited